%% PLOTS FOR CERTAINTY EQUIVALENT TASK
clear all;

addpath C:\Toolboxes\gramm
addpath D:\gramm\

% Load correct data matrix
mainpath = 'C:\Users\kojala\Dropbox\Projects\CE_task_analyses';
load(fullfile(mainpath,'MATLAB_Data','gainsdata_alphaestimated_LattimorePWF_iter200_new'));
load(fullfile(mainpath,'MATLAB_Data','lossesdata_alphaestimated_LattimorePWF_iter200_new'));

% Subjects
subjects = [1:20 22 23 29:37 39:42 44:50 52];
controlsub = [1:20 22 23];
gamblersub = [29:37 39:42 44:50 52];
% Remove subjects that have been excluded from group analyses (18, 29, 30, 40, 48, 52)
excluded = [18 29 30 40 48 52];
%excluded = 52; % Keep all included except true outlier 52
subjects = subjects(ismember(subjects,excluded)==0);
controlsub = controlsub(ismember(controlsub,excluded)==0);
gamblersub = gamblersub(ismember(gamblersub,excluded)==0);
resultdata_gains(ismember(resultdata_gains(:,1),excluded)==1,:) = [];
resultdata_losses(ismember(resultdata_losses(:,1),excluded)==1,:) = [];

placeboind = find(resultdata_gains(:,3)==1); % same for gains and losses
sulpirideind = find(resultdata_gains(:,3)==2);
controls = 1:length(controlsub);
gamblers = length(controlsub)+1:(length(controlsub)+length(gamblersub));

probsx = [1/6 2/6 3/6 4/6 5/6]; % Objective probability vector
objx = [0 probsx 1]; % Including 0 and 1 for fitted data
objxfit = 0:0.01:1;

pwf = 1;

% Compute fitted data points
% Values of delta and gamma according to Fox & Poldrack
yfit_canonical = computeFittedDatap(pwf, [0.8 0.6], objxfit);

% Over groups for gains placebo and sulpiride
% Placebo
gain_placebo(:,1) = median(resultdata_gains(placeboind,20)); % delta
gain_placebo(:,2) = median(resultdata_gains(placeboind,21)); % gamma
gain_placebo_IQR25 = quantile(resultdata_gains(placeboind,21),0.25); % gamma 25% quantile
gain_placebo_IQR75 = quantile(resultdata_gains(placeboind,21),0.75); % gamma 75% quantile
% Sulpiride
gain_sulpiride(:,1) = median(resultdata_gains(sulpirideind,20)); % delta
gain_sulpiride(:,2) = median(resultdata_gains(sulpirideind,21)); % gamma
gain_sulpiride_IQR25 = quantile(resultdata_gains(sulpirideind,21),0.25); % gamma 25% quantile
gain_sulpiride_IQR75 = quantile(resultdata_gains(sulpirideind,21),0.75); % gamma 75% quantile
% Compute fitted data points
yfit_gain_placebo = computeFittedDatap(pwf, gain_placebo, objxfit);
yfit_gain_placebo_IQR25 = computeFittedDatap(pwf, [gain_placebo(:,1) gain_placebo_IQR25], objxfit);
yfit_gain_placebo_IQR75 = computeFittedDatap(pwf, [gain_placebo(:,1) gain_placebo_IQR75], objxfit);
yfit_gain_sulpiride = computeFittedDatap(pwf, gain_sulpiride, objxfit);
yfit_gain_sulpiride_IQR25 = computeFittedDatap(pwf, [gain_sulpiride(:,1) gain_sulpiride_IQR25], objxfit);
yfit_gain_sulpiride_IQR75 = computeFittedDatap(pwf, [gain_sulpiride(:,1) gain_sulpiride_IQR75], objxfit);

yfit_gain(1,:) = yfit_gain_placebo;
yfit_gain(2,:) = yfit_gain_sulpiride;
yfit_gain_IQR_placebo(1,:) = yfit_gain_placebo_IQR75;
yfit_gain_IQR_placebo(2,:) = yfit_gain_placebo_IQR25;
yfit_gain_IQR_sulpiride(1,:) = yfit_gain_sulpiride_IQR75;
yfit_gain_IQR_sulpiride(2,:) = yfit_gain_sulpiride_IQR25;

% Take medians for each group and drug condition
% GAINS
% Controls
% Placebo
gain_control_placebo(:,1) = median(resultdata_gains(placeboind(controls),20)); % delta
gain_control_placebo(:,2) = median(resultdata_gains(placeboind(controls),21)); % gamma
% Sulpiride
gain_control_sulpiride(:,1) = median(resultdata_gains(sulpirideind(controls),20)); % delta
gain_control_sulpiride(:,2) = median(resultdata_gains(sulpirideind(controls),21)); % gamma

% Gamblers
% Placebo
gain_gambler_placebo(:,1) = median(resultdata_gains(placeboind(gamblers),20)); % delta
gain_gambler_placebo(:,2) = median(resultdata_gains(placeboind(gamblers),21)); % gamma
% Sulpiride
gain_gambler_sulpiride(:,1) = median(resultdata_gains(sulpirideind(gamblers),20)); % delta
gain_gambler_sulpiride(:,2) = median(resultdata_gains(sulpirideind(gamblers),21)); % gamma

% LOSSES
% Controls
% Placebo
loss_control_placebo(:,1) = median(resultdata_losses(placeboind(controls),20)); % delta
loss_control_placebo(:,2) = median(resultdata_losses(placeboind(controls),21)); % gamma
% Sulpiride
loss_control_sulpiride(:,1) = median(resultdata_losses(sulpirideind(controls),20)); % delta
loss_control_sulpiride(:,2) = median(resultdata_losses(sulpirideind(controls),21)); % gamma

% Gamblers
% Placebo
loss_gambler_placebo(:,1) = median(resultdata_losses(placeboind(gamblers),20)); % delta
loss_gambler_placebo(:,2) = median(resultdata_losses(placeboind(gamblers),21)); % gamma
% Sulpiride
loss_gambler_sulpiride(:,1) = median(resultdata_losses(sulpirideind(gamblers),20)); % delta
loss_gambler_sulpiride(:,2) = median(resultdata_losses(sulpirideind(gamblers),21)); % gamma

% For placebo and sulpiride conditions, for both gains and losses
yfit_gain_control_placebo = computeFittedDatap(pwf, gain_control_placebo, objxfit);
yfit_gain_control_sulpiride = computeFittedDatap(pwf, gain_control_sulpiride, objxfit);

yfit_gain_gambler_placebo = computeFittedDatap(pwf, gain_gambler_placebo, objxfit);
yfit_gain_gambler_sulpiride = computeFittedDatap(pwf, gain_gambler_sulpiride, objxfit);

yfit_loss_control_placebo = computeFittedDatap(pwf, loss_control_placebo, objxfit);
yfit_loss_control_sulpiride = computeFittedDatap(pwf, loss_control_sulpiride, objxfit);

yfit_loss_gambler_placebo = computeFittedDatap(pwf, loss_gambler_placebo, objxfit);
yfit_loss_gambler_sulpiride = computeFittedDatap(pwf, loss_gambler_sulpiride, objxfit);

%----

yfit_gain_controls(1,:) = yfit_gain_control_placebo;
yfit_gain_controls(2,:) = yfit_gain_control_sulpiride;

yfit_gain_gamblers(1,:) = yfit_gain_gambler_placebo;
yfit_gain_gamblers(2,:) = yfit_gain_gambler_sulpiride;

yfit_loss_controls(1,:) = yfit_loss_control_placebo;
yfit_loss_controls(2,:) = yfit_loss_control_sulpiride;

yfit_loss_gamblers(1,:) = yfit_loss_gambler_placebo;
yfit_loss_gamblers(2,:) = yfit_loss_gambler_sulpiride;

%----
% COMPUTE FITTED CURVES AND TAKE MEDIAN AFTERWARD

% Compute individual fitted curves
for s = 1:length([controls gamblers])
    yfit_gain_placebo_ind(s,:) = computeFittedDatap(pwf, resultdata_gains(placeboind(s),20:21), objxfit);
    yfit_gain_sulpiride_ind(s,:) = computeFittedDatap(pwf, resultdata_gains(sulpirideind(s),20:21), objxfit);
    yfit_loss_placebo_ind(s,:) = computeFittedDatap(pwf, resultdata_losses(placeboind(s),20:21), objxfit);
    yfit_loss_sulpiride_ind(s,:) = computeFittedDatap(pwf, resultdata_losses(sulpirideind(s),20:21), objxfit);
end

% Take medians
yfit_gain_placebo_median = median(yfit_gain_placebo_ind);
yfit_gain_sulpiride_median = median(yfit_gain_sulpiride_ind);
yfit_loss_placebo_median = median(yfit_loss_placebo_ind);
yfit_loss_sulpiride_median = median(yfit_loss_sulpiride_ind);

%% Canonical PWF
g = gramm('x',objxfit,'y',yfit_canonical);
g.geom_line();
g.geom_abline();
g.set_title('Probability weighting function');
g.set_names('x','p - objective probability','y','w(p) - subjective probability weight');
g.set_color_options('hue_range',[-100 150],'chroma',0,'lightness',10);
g.set_line_options('base_size',1.5);
g.set_text_options('font','Arial',...
    'base_size',10,...
    'title_scaling',1,...
    'legend_title_scaling',1);
g.axe_property('XLim',[0 1],'YLim',[0 1]);
figure('Position',[100 100 700 600]);
g.draw();
g.export('file_name','PWF_canonical','export_path',fullfile(mainpath,'Plots','GrammPlots'),'file_type','svg');
g.export('file_name','PWF_canonical','export_path',fullfile(mainpath,'Plots','GrammPlots'),'file_type','eps');
g.export('file_name','PWF_canonical','export_path',fullfile(mainpath,'Plots','GrammPlots'),'file_type','png');


%% MEDIANS SEPARATELY FOR BOTH CONDITIONS FOR ALL SUBJECTS
% Gains

% Placebo
subj_gp = [NaN median(resultdata_gains(placeboind,15:19)) NaN];
% Sulpiride
subj_gs = [NaN median(resultdata_gains(sulpirideind,15:19)) NaN];

Standard error of the median (REPLACE THESE)
subj_gp_err = [NaN std(resultdata_gains(placeboind,15:19))/sqrt(length(placeboind)) NaN];
subj_gs_err = [NaN std(resultdata_gains(sulpirideind,15:19))/sqrt(length(sulpirideind)) NaN];

% Gains
name = 'Figure2';
figure2 = figure('name', name);
hold on;
plot(objxfit,yfit_gain(1,:),'-b','LineWidth',1.3);
plot(objxfit,yfit_gain(2,:),'-r','LineWidth',1.3);
plot(objxfit,yfit_gain_placebo_IQR25,'-b','LineWidth',0.3);
plot(objxfit,yfit_gain_placebo_IQR75,'-b','LineWidth',0.3);
plot(objxfit,yfit_gain_sulpiride_IQR25,'-r','LineWidth',0.3);
plot(objxfit,yfit_gain_sulpiride_IQR75,'-r','LineWidth',0.3);
[ph,msg] = jbfill(objxfit,yfit_gain_IQR_placebo(1,:),yfit_gain_IQR_placebo(2,:),'b','b',1,0.2);
hold on
[ph,msg] = jbfill(objxfit,yfit_gain_IQR_sulpiride(1,:),yfit_gain_IQR_sulpiride(2,:),'r','r',1,0.2);
hold on
plot(objx,objx,'--k');
xlim([0 1]);
ylim([0 1]);
xlabel('\it{p} \rm{- objective probability}');
ylabel('\it{w(p)} \rm{- subjective probability weight}');
legend('Placebo','Sulpiride','Location','northwest');
legend boxoff

%% MEDIANS SEPARATELY FOR BOTH CONDITIONS AND GROUPS

% % Gains
% % Controls Placebo
% subj_gcp = [NaN median(resultdata_gains(placeboind(controls),15:19)) NaN];
% % Controls Sulpiride
% subj_gcs = [NaN median(resultdata_gains(sulpirideind(controls),15:19)) NaN];
% 
% % Gamblers Placebo
% subj_ggp = [NaN median(resultdata_gains(placeboind(gamblers),15:19)) NaN];
% % Gamblers Sulpiride
% subj_ggs = [NaN median(resultdata_gains(sulpirideind(gamblers),15:19)) NaN];
% 
% % Losses
% % Controls Placebo
% subj_lcp = [NaN median(resultdata_losses(placeboind(controls),15:19)) NaN];
% % Controls Sulpiride
% subj_lcs = [NaN median(resultdata_losses(sulpirideind(controls),15:19)) NaN];
% 
% % Gamblers Placebo
% subj_lgp = [NaN median(resultdata_losses(placeboind(gamblers),15:19)) NaN];
% % Gamblers Sulpiride
% subj_lgs = [NaN median(resultdata_losses(sulpirideind(gamblers),15:19)) NaN];
% 
% % Standard error of the median (REPLACE THESE)
% subj_gcp_err = [NaN std(resultdata_gains(placeboind(controls),15:19))/sqrt(length(placeboind(controls))) NaN];
% subj_gcs_err = [NaN std(resultdata_gains(sulpirideind(controls),15:19))/sqrt(length(sulpirideind(controls))) NaN];
% subj_ggp_err = [NaN std(resultdata_gains(placeboind(gamblers),15:19))/sqrt(length(placeboind(gamblers))) NaN];
% subj_ggs_err = [NaN std(resultdata_gains(sulpirideind(gamblers),15:19))/sqrt(length(sulpirideind(gamblers))) NaN];
% subj_lcp_err = [NaN std(resultdata_losses(placeboind(controls),15:19))/sqrt(length(placeboind(controls))) NaN];
% subj_lcs_err = [NaN std(resultdata_losses(sulpirideind(controls),15:19))/sqrt(length(sulpirideind(controls))) NaN];
% subj_lgp_err = [NaN std(resultdata_losses(placeboind(gamblers),15:19))/sqrt(length(placeboind(gamblers))) NaN];
% subj_lgs_err = [NaN std(resultdata_losses(sulpirideind(gamblers),15:19))/sqrt(length(sulpirideind(gamblers))) NaN];

% Gains Controls
name = 'gains_controls';
fig = figure('name', name);
hold on;
% errorbar(objx,subj_gcp,subj_gcp_err,'bo','MarkerSize',5,'MarkerFaceColor','b');
% errorbar(objx,subj_gcs,subj_gcs_err,'ro','MarkerSize',5,'MarkerFaceColor','r');
plot(objxfit,yfit_gain_controls(1,:),'-b','LineWidth',1.3); % Placebo
plot(objxfit,yfit_gain_controls(2,:),'-r','LineWidth',1.3); % Sulpiride
plot(objx(:),objx(:),'--k');
xlim([0 1]);
xlabel('p - objective probability');
ylabel('w(p) - subjective probability weight');
title('Gains Controls');
legend('Placebo','Sulpiride','Location','northwest');
legend boxoff
%saveas(fig, ['Plots\SubjectiveProbabilityWeights\Gains\' name]);

% Gains Gamblers
name = 'gains_gamblers';
fig = figure('name', name);
hold on;
% errorbar(objx,subj_ggp,subj_ggp_err,'bo','MarkerSize',5,'MarkerFaceColor','b');
% errorbar(objx,subj_ggs,subj_ggs_err,'ro','MarkerSize',5,'MarkerFaceColor','r');
plot(objxfit,yfit_gain_gamblers(1,:),'-b','LineWidth',1.3);
plot(objxfit,yfit_gain_gamblers(2,:),'-r','LineWidth',1.3);
plot(objx(:),objx(:),'--k');
xlim([0 1]);
xlabel('p - objective probability');
ylabel('w(p) - subjective probability weight');
title('Gains Gamblers');
legend('Placebo','Sulpiride','Location','northwest');
legend boxoff

% Losses Controls
name = 'losses_controls';
fig = figure('name', name);
hold on;
% errorbar(objx,subj_lcp,subj_lcp_err,'bo','MarkerSize',5,'MarkerFaceColor','b');
% errorbar(objx,subj_lcs,subj_lcs_err,'ro','MarkerSize',5,'MarkerFaceColor','r');
plot(objxfit,yfit_loss_controls(1,:),'-b','LineWidth',1.3); % Placebo
plot(objxfit,yfit_loss_controls(2,:),'-r','LineWidth',1.3); % Sulpiride
plot(objx(:),objx(:),'--k');
xlim([0 1]);
xlabel('p - objective probability');
ylabel('w(p) - subjective probability weight');
title('Losses Controls');
legend('Placebo','Sulpiride','Location','northwest');
legend boxoff

% Losses Gamblers
name = 'losses_gamblers';
fig = figure('name', name);
hold on;
% errorbar(objx,subj_lgp,subj_lgp_err,'bo','MarkerSize',5,'MarkerFaceColor','b');
% errorbar(objx,subj_lgs,subj_lgs_err,'ro','MarkerSize',5,'MarkerFaceColor','r');
plot(objxfit,yfit_loss_gamblers(1,:),'-b','LineWidth',1.3); % Placebo
plot(objxfit,yfit_loss_gamblers(2,:),'-r','LineWidth',1.3); % Sulpiride
plot(objx(:),objx(:),'--k');
xlim([0 1]);
xlabel('p - objective probability');
ylabel('w(p) - subjective probability weight');
title('Losses Gamblers');
legend('Placebo','Sulpiride','Location','northwest');
legend boxoff

%% MEDIAN CURVES GAINS SULPIRIDE VS. PLACEBO OVER GROUPS

% name = 'Figure2mdn';
% figure2mdn = figure('name', name);
% hold on;
% errorbar(objx,subj_gp,subj_gp_err,'bo','MarkerSize',5,'MarkerFaceColor','b');
% errorbar(objx,subj_gs,subj_gs_err,'ro','MarkerSize',5,'MarkerFaceColor','r');
% plot(objxfit,yfit_gain_placebo_median,'-b');
% plot(objxfit,yfit_gain_sulpiride_median,'-r');
% plot(objx,objx,'--k');
% xlim([0 1]);
% xlabel('\it{p} \rm{- objective probability}');
% ylabel('\it{w(p)} \rm{- subjective probability weight}');
% legend('Placebo', 'Sulpiride', 'Location', 'northwest');
% legend boxoff

%% UNUSED FIGURES:
% INDIVIDUAL CURVES WITH MEDIAN

% % Gains controls
% figure
% hold on;
% plot(objxfit,yfit_gain_control_placebo,'-b','LineWidth',3);
% plot(objxfit,yfit_gain_control_sulpiride,'-r','LineWidth',3);
% for s = controls
%     plot1 = plot(objxfit,yfit_gain_placebo_ind(s,:),'-b','LineWidth',0.5);
%     plot1.Color(4) = 0.2;
%     plot2 = plot(objxfit,yfit_gain_sulpiride_ind(s,:),'-r','LineWidth',0.5);
%     plot2.Color(4) = 0.2;
% end
% plot(objx,objx,'--k');
% xlim([0 1]);
% xlabel('\it{p} \rm{- objective probability}');
% ylabel('\it{w(p)} \rm{- subjective probability weight}');
% legend('Placebo', 'Sulpiride', 'Location', 'northwest');
% legend boxoff
% 
% % Gains gamblers
% figure
% hold on;
% for s = gamblers
%     plot(objxfit,yfit_gain_placebo_ind(s,:),'-b','LineWidth',0.5);
%     plot(objxfit,yfit_gain_sulpiride_ind(s,:),'-r','LineWidth',0.5);
% end
% plot(objxfit,yfit_gain_gambler_placebo,'-b','LineWidth',3);
% plot(objxfit,yfit_gain_gambler_sulpiride,'-r','LineWidth',3);
% plot(objx,objx,'--k');
% xlim([0 1]);
% xlabel('\it{p} \rm{- objective probability}');
% ylabel('\it{w(p)} \rm{- subjective probability weight}');
% legend('Placebo', 'Sulpiride', 'Location', 'northwest');
% legend boxoff

% Losses controls

% Losses gamblers