# R version 3.3.0 (2016-05-03)
# required packages:
# ggplot2 version 2.1.0
# cowplot 0.6.2

library(ggplot2)
library(cowplot)
library(extrafont)
library(readxl)
loadfonts(quiet=TRUE)
loadfonts(device = "postscript", quiet=TRUE)

setwd("C:/Users/kojala/Dropbox/Projects/CE_task_analyses/Plots/Rplots") # set working directory
#source("rgar_stats.txt") # file also available here: https://github.com/GRousselet/rstats

# load gammagains
gammagains <- read_excel("gamma_gains_iter200.xlsx")
#if (dim(gammagains)[2] == 5){gammagains <- gammagains[,2:5]}
gammagains$participant <- factor(gammagains$participant)

# ----------------------------------------------------
# 1D scatterplots = stripcharts of differences -------
value <- gammagains$value[gammagains$condition=="Sulpiride"]-gammagains$value[gammagains$condition=="Placebo"]
participant <- gammagains$participant[gammagains$condition=="Sulpiride"]
group <- gammagains$group[gammagains$condition=="Sulpiride"]
diff <- data.frame(participant,group,value)
# ggplot(diff, aes(x=group, y=value)) +
#   geom_point(shape = 21, colour = 'red', fill = "white", size = 3, stroke = 1)
set.seed(8)

diffboxplot <- ggplot(diff,aes(x="value",y=value)) +
  geom_boxplot(width = 0.5) +
  theme_bw() +
  #scale_shape_manual(values=c(22,21)) +
  #scale_fill_manual(values = c("grey70", "grey95")) +
  #scale_colour_manual(values = c("grey5","grey5")) +
  theme(legend.position="none",
        axis.text.x = element_text(colour="grey20",size=8),
        axis.text.y = element_text(colour="grey20",size=8),  
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        plot.title = element_text(family="sans",colour="grey20",size=8),
        plot.margin = unit(c(5.5,5.5,5.5,5.5), "pt")) +
  # plot.margin = unit(c(150,200,5.5,5.5), "pt")
  labs(title="Differences: Sulpiride - placebo") +
  theme(plot.title = element_text(hjust = 0.5)) +
  scale_y_continuous(limits=c(-3.5, 3.5),breaks=seq(-3,3,1)) 
diffboxplot

# diffstrip <- ggplot(diff, aes(x=group, y=value, fill=group, colour=group, shape=group)) +
#   geom_abline(intercept = 0, slope = 0) +
#   geom_jitter(position=position_jitter(0.3), size=4, stroke=1) +
#   theme_bw() +
#   scale_shape_manual(values=c(22,21)) +
#   scale_fill_manual(values = c("grey70", "grey95")) +
#   scale_colour_manual(values = c("grey5","grey5")) +
#   theme(legend.position="none",
#         axis.text.x = element_text(colour="grey20",size=8),
#         axis.text.y = element_text(colour="grey20",size=8),  
#         axis.title.x = element_blank(),
#         axis.title.y = element_blank(),
#         plot.title = element_text(family="sans",colour="grey20",size=8),
#         plot.margin = unit(c(5.5,5.5,5.5,5.5), "pt")) +
#         # plot.margin = unit(c(150,200,5.5,5.5), "pt")
#   labs(title="Differences: Sulpiride - placebo") +
#   theme(plot.title = element_text(hjust = 0.5)) +
#   scale_y_continuous(limits=c(-1, 3.5),breaks=seq(-2,3,1)) 
# diffstrip
# margin(t = 0, r = 0, b = 0, l = 0, unit = "pt")
# theme_grey()

# ----------------------------------------------------
# stripchart + linked observations -----------------
p <- ggplot(gammagains, aes(x=condition, y=value, fill=condition, group=participant,shape=group)) +
  theme_bw() +
  geom_line(size=0.7, alpha=1) +
  geom_point(colour = "black", size = 4, stroke = 1) +
  scale_shape_manual(values=c(22,21)) +
  scale_fill_manual(values = c("grey60", "grey90")) +
  theme(axis.text.x = element_text(colour="grey20",size=8),
        axis.text.y = element_text(colour="grey20",size=8),  
        axis.title.x = element_blank(),
        axis.title.y = element_blank(),
        plot.title = element_text(colour="grey20",size=8),
        legend.position="none",
        # plot.margin = unit(c(150,100,5.5,5.5), "pt")
        plot.margin = unit(c(5.5,5.5,5.5,5.5), "pt")) +
        labs(title="Paired observations") +
        theme(plot.title = element_text(hjust = 0.5)) +
  scale_y_continuous(limits=c(0, 4),breaks=seq(0,5,1))
# p
linkedstrip <- p + facet_grid(. ~ group) +
  theme(strip.text.x = element_text(size = 8, colour = "black"),
        strip.background = element_rect(colour="darkgrey", fill="darkgrey"))
linkedstrip


# ----------------------------------------------------
# Make final figure combining 4 subplots --------------

set.seed(8)
plot_grid(diffboxplot, linkedstrip, labels=c("(a)", "(b)"), 
ncol = 2, nrow = 1, rel_widths = c(0.3, 1), rel_heights = c(1, 1),label_size = 8, hjust = 0,scale=.95)

#ggsave(filename='figure1AB.tiff',width=10,height=11)
#ggplot2::ggsave(filename='figure2AB.bmp')
