datapath = 'C:\Users\kojala\Dropbox\Projects\CE_task_analyses\MATLAB_Data';

gainsdata = importdata(fullfile(datapath,'gainsdata_alphaestimated_LattimorePWF_iter200_new.mat'));
lossesdata = importdata(fullfile(datapath,'lossesdata_alphaestimated_LattimorePWF_iter200_new.mat'));

subjects = [1:20 22 23 29:37 39:42 44:50 52]; % all subjects

placeboind = find(gainsdata(:,3)==1); % indices for drug conditions
sulpirideind = find(gainsdata(:,3)==2); % same for gains and losses

x = [1200 600 1200 600 1000 1200]; % amount x on offer with probability p
y = [0 0 600 300 400 900]; % amount y on offer with probability 1-p
% these amounts are shown as e.g. -1200 for losses but here positive for
% loss domain as well and transformed into negative only after calculations
% to avoid imaginary numbers in interaction with non-integer exponents
p = [1/6 2/6 3/6 4/6 5/6]; % probabilities p
    
for n = 1:2 % Over gains and losses separately
    
    if n == 1 % gains
        data = gainsdata;     
    elseif n == 2 % losses
        data = lossesdata;
    end

    for sub = 1:length(subjects)
        
        % % Placebo condition
        % 1st estimation step for alpha and w(2/6), input data Certainty
        % Equivalents
        alphaP = data(placeboind(sub),14); % alpha parameter estimate
        wp26P = data(placeboind(sub),16); % w(2/6) parameter estimate
        observed_dataP1 = data(placeboind(sub),5:10); % actual observed Certainty Equivalents
        
        % 2nd estimation step for delta and gamma, input data subjective
        % probability weights (calculated based on alpha and different set of
        % Certainty Equivalents with varying probabilities, and subjective
        % probability weight for p = 2/6 is the estimated w(2/6).
        deltaP = data(placeboind(sub),20); % delta parameter estimate
        gammaP = data(placeboind(sub),21); % gamma parameter estimate
        observed_dataP2 = data(placeboind(sub),15:19); % calculated w(p)
        
        % Pack data together
        dataP1 = [x y observed_dataP1];
        dataP2 = [p observed_dataP2];
        
        acovP1 = mlecov([alphaP wp26P],dataP1,'logpdf',@ce_loglik); % calculate covariance matrix 1st estimation step
        acovP2 = mlecov([deltaP gammaP],dataP2,'logpdf',@wp_loglik); % calculate covariance matrix 2nd estimation step
        
        % % Sulpiride condition
        % 1st estimation step for alpha and w(2/6), input data Certainty
        % Equivalents
        alphaS = data(sulpirideind(sub),14); % alpha parameter estimate
        wp26S = data(sulpirideind(sub),16); % w(2/6) parameter estimate
        observed_dataS1 = data(sulpirideind(sub),5:10); % actual observed Certainty Equivalents
        
        % 2nd estimation step for delta and gamma, input data subjective
        % probability weights (calculated based on alpha and different set of
        % Certainty Equivalents with varying probabilities, and subjective
        % probability weight for p = 2/6 is the estimated w(2/6).
        deltaS = data(sulpirideind(sub),20); % delta parameter estimate
        gammaS = data(sulpirideind(sub),21); % gamma parameter estimate
        observed_dataS2 = data(sulpirideind(sub),15:19); % calculated w(p)
        
        % Pack data together
        dataS1 = [x y observed_dataS1];
        dataS2 = [p observed_dataS2];
        
        acovS1 = mlecov([alphaS wp26S],dataS1,'logpdf',@ce_loglik); % calculate covariance matrix 1st estimation step
        acovS2 = mlecov([deltaS gammaS],dataS2,'logpdf',@wp_loglik); % calculate covariance matrix 2nd estimation step
        
        % Standard error and covariance for the parameters
        % Placebo
        % 1st estimation step
        sderrorP_alpha(sub) = sqrt(acovP1(1,1));
        sderrorP_wp26(sub) = sqrt(acovP1(2,2));
        covarP_alpha_w26p(sub) = acovP1(1,2);
        % 2nd estimation step
        sderrorP_gamma(sub) = sqrt(acovP2(1,1));
        sderrorP_delta(sub) = sqrt(acovP2(2,2));
        covarP_delta_gamma(sub) = acovP2(1,2);
        
        % Sulpiride
        % 1st estimation step
        sderrorS_alpha(sub) = sqrt(acovS1(1,1));
        sderrorS_wp26(sub) = sqrt(acovS1(2,2));
        covarS_alpha_w26p(sub) = acovS1(1,2);
        % 2nd estimation step
        sderrorS_gamma(sub) = sqrt(acovS2(1,1));
        sderrorS_delta(sub) = sqrt(acovS2(2,2));
        covarS_delta_gamma(sub) = acovS2(1,2);
        
    end
    
    % Save data for gains and losses separately
    % standard errors and covariances (model fit)
    if n == 1
        save(fullfile(datapath,'modelfit_mlecov_gains_allsubs.mat'), 'sderrorP_alpha', 'sderrorP_wp26', ...
            'covarP_alpha_w26p', 'sderrorS_alpha', 'sderrorS_wp26', 'covarS_alpha_w26p',...
            'sderrorP_gamma', 'sderrorP_delta', 'covarP_delta_gamma', 'sderrorS_gamma',...
            'sderrorS_delta', 'covarS_delta_gamma');
    elseif n == 2
        save(fullfile(datapath,'modelfit_mlecov_losses_allsubs.mat'), 'sderrorP_alpha', 'sderrorP_wp26', ...
            'covarP_alpha_w26p', 'sderrorS_alpha', 'sderrorS_wp26', 'covarS_alpha_w26p',...
            'sderrorP_gamma', 'sderrorP_delta', 'covarP_delta_gamma', 'sderrorS_gamma',...
            'sderrorS_delta', 'covarS_delta_gamma');
    end
    
end