datapath = 'C:\Users\kojala\Dropbox\Projects\CE_task_analyses\MATLAB_Data';

gainsdata = importdata(fullfile(datapath,'gainsdata_alphaestimated_LattimorePWF_iter200_new.mat'));
lossesdata = importdata(fullfile(datapath,'lossesdata_alphaestimated_LattimorePWF_iter200_new.mat'));
gainsfit = importdata(fullfile(datapath,'modelfit_mlecov_gains_allsubs.mat')); % model covariance matrix data
lossesfit = importdata(fullfile(datapath,'modelfit_mlecov_losses_allsubs.mat'));

subjects = [1:20 22 23 29:37 39:42 44:50 52]; % all subjects

placeboind = find(gainsdata(:,3)==1); % indices for drug conditions
sulpirideind = find(gainsdata(:,3)==2); % same for gains and losses

% Alpha & w(2/6) - 1st fitting step
alpha = [gainsdata(placeboind,14) gainsdata(sulpirideind,14) lossesdata(placeboind,14) lossesdata(sulpirideind,14)];
alphaSE = [gainsfit.sderrorP_alpha' gainsfit.sderrorS_alpha' lossesfit.sderrorP_alpha' lossesfit.sderrorS_alpha']; % standard error
wp26 = [gainsdata(placeboind,16) gainsdata(sulpirideind,16) lossesdata(placeboind,16) lossesdata(sulpirideind,16)];
wp26SE = [gainsfit.sderrorP_wp26' gainsfit.sderrorS_wp26' lossesfit.sderrorP_wp26' lossesfit.sderrorS_wp26']; % standard error

subvect = 1:length(subjects);
excl = [18 29 30 40 48 52]; % excluded subjects
excluded = subvect(ismember(subjects,excl));

conditions = {'Gains, Placebo' 'Gains, Sulpiride' 'Losses, Placebo' 'Losses, Sulpiride'};

% Plot parameter estimates and standard errors for each subject
figure;
set(gcf,'units','points','position',[0,0,800,600])
st = suptitle('Parameter estimate values with SE, N = 43');
set(st, 'FontSize', 12)
hold on

for i = 1:length(conditions) % loop over all conditions
    
    subplot(2,2,i)
    h = plot(alpha(:,i),wp26(:,i),'ob','MarkerFaceColor','b','MarkerSize',3);
    hold on
    [hdx, hdy] = errorbarxy(alpha(:,i),wp26(:,i),alphaSE(:,i),wp26SE(:,i));
    
    for e = excluded % mark excluded subjects with red
        plot(alpha(excluded,i),wp26(excluded,i),'or','MarkerFaceColor','r','MarkerSize',3)
        hdx(e).Color = 'red';
        hdy(e).Color = 'red';
        text(alpha(e,i)+0.05,wp26(e,i)+0.01,num2str(subjects(e)))
    end
    
    xlabel('Alpha')
    xmaxlim = nansum([max(alpha(:,i)) alphaSE(alpha(:,i)==max(alpha(:,i)),i)]);
    xlim([0 xmaxlim])
    ylim([0 1])
    ylabel('w(2/6)')
    t = title(conditions{i});
    set(t, 'FontSize', 10)
    
end

% Delta & gamma  - 2nd fitting step
delta = [gainsdata(placeboind,20) gainsdata(sulpirideind,20) lossesdata(placeboind,20) lossesdata(sulpirideind,20)];
deltaSE = [gainsfit.sderrorP_delta' gainsfit.sderrorS_delta' lossesfit.sderrorP_delta' lossesfit.sderrorS_delta'];
gamma = [gainsdata(placeboind,21) gainsdata(sulpirideind,21) lossesdata(placeboind,21) lossesdata(sulpirideind,21)];
gammaSE = [gainsfit.sderrorP_gamma' gainsfit.sderrorS_gamma' lossesfit.sderrorP_gamma' lossesfit.sderrorS_gamma'];

conditions = {'Gains, Placebo' 'Gains, Sulpiride' 'Losses, Placebo' 'Losses, Sulpiride'};

figure;
set(gcf,'units','points','position',[0,0,800,600])
st = suptitle('Parameter estimate values with SE, N = 43');
set(st, 'FontSize', 12)
hold on

for i = 1:length(conditions)
    
    subplot(2,2,i)
    h = plot(gamma(:,i),delta(:,i),'ob','MarkerFaceColor','b','MarkerSize',3);
    hold on
    [hdx, hdy] = errorbarxy(gamma(:,i),delta(:,i),gammaSE(:,i),deltaSE(:,i));
    
    for e = excluded
        plot(gamma(excluded,i),delta(excluded,i),'or','MarkerFaceColor','r','MarkerSize',3)
        hdx(e).Color = 'red';
        hdy(e).Color = 'red';
        text(gamma(e,i)+0.01,delta(e,i)+0.01,num2str(subjects(e)))
    end
    
    xlabel('Gamma')
    xmaxlimd = nansum([max(delta(:,i)) deltaSE(delta(:,i)==max(delta(:,i)),i)]);
    xmaxlimg = nansum([max(gamma(:,i)) gammaSE(gamma(:,i)==max(gamma(:,i)),i)]);
    ylim([0 xmaxlimd])
    xlim([0 xmaxlimg])
    ylabel('Delta')
    t = title(conditions{i});
    set(t, 'FontSize', 10)
    
end