% PLOTTING RESNORM (goodness-of-fit)
clear all
datapath = 'C:\Users\kojala\Dropbox\Projects\CE_task_analyses\MATLAB_Data\Resnorm';

subjects = [1:20 22 23 29:37 39:42 44:50 52]; % all subjects

titles = {'Resnorm Alpha & w(2/6) Gains Placebo' 'Resnorm Alpha & w(2/6) Gains Sulpiride' 'Resnorm Alpha & w(2/6) Losses Placebo' 'Resnorm Alpha & w(2/6) Losses Sulpiride'...
    'Resnorm Delta & Gamma Gains Placebo' 'Resnorm Delta & Gamma Gains Sulpiride' 'Resnorm Delta & Gamma Losses Placebo' 'Resnorm Delta & Gamma Losses Sulpiride'};

for sub = 1:length(subjects) % retrieve resnorm data for each subject
    
rndata(1,:) = importdata(fullfile(datapath,['resnormdata_aw26_gains_iter200_subject' num2str(subjects(sub)) '_drug1.mat']));
rndata(2,:) = importdata(fullfile(datapath,['resnormdata_aw26_gains_iter200_subject' num2str(subjects(sub)) '_drug2.mat']));
rndata(3,:) = importdata(fullfile(datapath,['resnormdata_aw26_losses_iter200_subject' num2str(subjects(sub)) '_drug1.mat']));
rndata(4,:) = importdata(fullfile(datapath,['resnormdata_aw26_losses_iter200_subject' num2str(subjects(sub)) '_drug2.mat']));

rndata(5,:) = importdata(fullfile(datapath,['resnormdata_dg_gains_iter200_subject' num2str(subjects(sub)) '_drug1.mat']));
rndata(6,:) = importdata(fullfile(datapath,['resnormdata_dg_gains_iter200_subject' num2str(subjects(sub)) '_drug2.mat']));
rndata(7,:) = importdata(fullfile(datapath,['resnormdata_dg_losses_iter200_subject' num2str(subjects(sub)) '_drug1.mat']));
rndata(8,:) = importdata(fullfile(datapath,['resnormdata_dg_losses_iter200_subject' num2str(subjects(sub)) '_drug2.mat']));

for i = 1:size(rndata,1)
    
    minrn(sub,i) = min(rndata(i,:)); % take the minimum resnorm (best)
    
end

end

subvect = 1:size(minrn,1);
% excluded participants
excl = [18 29 30 40 48 52];
excluded = subvect(ismember(subjects,excl));
% included participants
included = subvect(~ismember(subjects,excl));

% Alpha and w(2/6)
resnorm_awp = [mean(minrn(included,1)) mean(minrn(excluded,1)); mean(minrn(included,2)) mean(minrn(excluded,2));...
     mean(minrn(included,3)) mean(minrn(excluded,3));  mean(minrn(included,4)) mean(minrn(excluded,4))];
resnorm_awp_se = [std(minrn(included,1))/sqrt(length(included)) std(minrn(excluded,1))/sqrt(length(excluded));...
     std(minrn(included,2))/sqrt(length(included)) std(minrn(excluded,2))/sqrt(length(excluded));...
     std(minrn(included,3))/sqrt(length(included)) std(minrn(excluded,3))/sqrt(length(excluded));...
     std(minrn(included,4))/sqrt(length(included)) std(minrn(excluded,4))/sqrt(length(excluded))];
 
figure; hBar = bar(resnorm_awp);
set(gca,'XTick',1:4,'xTickLabel',{'Gains Placebo' 'Gains Sulpiride' 'Losses Placebo' 'Losses Sulpiride'})
ylabel('Resnorm')
title('Mean resnorms for alpha and w(2/6) fitting step')
legend('Included participants','Excluded participants','Location','northwest')
hold on

for i = 1:length(hBar)
    hb = get(get(hBar(i),'Children'), 'XData');
    midbar = mean(hb);
    errorbar(midbar, resnorm_awp(:,i), resnorm_awp_se(:,i), 'r.') % plotting errors
end


% Delta and gamma
resnorm_dg = [mean(minrn(included,5)) mean(minrn(excluded,5)); mean(minrn(included,6)) mean(minrn(excluded,6));...
     mean(minrn(included,7)) mean(minrn(excluded,7));  mean(minrn(included,8)) mean(minrn(excluded,8))];
resnorm_dg_se = [std(minrn(included,5))/sqrt(length(included)) std(minrn(excluded,5))/sqrt(length(excluded));...
     std(minrn(included,6))/sqrt(length(included)) std(minrn(excluded,6))/sqrt(length(excluded));...
     std(minrn(included,7))/sqrt(length(included)) std(minrn(excluded,7))/sqrt(length(excluded));...
     std(minrn(included,8))/sqrt(length(included)) std(minrn(excluded,8))/sqrt(length(excluded))];
 
figure; hBar = bar(resnorm_dg);
set(gca,'XTick',1:4,'xTickLabel',{'Gains Placebo' 'Gains Sulpiride' 'Losses Placebo' 'Losses Sulpiride'})
ylabel('Resnorm')
title('Mean resnorms for delta and gamma fitting step')
legend('Included participants','Excluded participants','Location','northeast')
hold on

for i = 1:length(hBar)
    hb = get(get(hBar(i),'Children'), 'XData');
    midbar = mean(hb);
    errorbar(midbar, resnorm_dg(:,i), resnorm_dg_se(:,i), 'r.') % plotting errors
end