function CE_noise = simulate_noisydata(resultdata,rows,order,gains)

% Noise calculated for log / log-odds transformed values to avoid going to
% negative if noise > value. 

for r = 1:rows % Subject and condition (2 drug conditions per subject)
    
    % Estimated parameter values
    alpha = resultdata(r,14);
    delta = resultdata(r,20);
    gamma = resultdata(r,21);
    wp26 = resultdata(r,16);
    
    % Data used for the estimation
    CE = resultdata(r,5:10);
    wp = resultdata(r,[15 17:19]); % and w(2/6) from the 1st step
    
    % Fitted data with parameter estimates
    % 1st step: CEs from the value function
    if gains==true;
        vx(r,:) = order(:,1).^alpha; % Value function of x
        vy(r,:) = order(:,2).^alpha; % Value function of y
        CEfit = (wp26*(vx(r,2:7)-vy(r,2:7))+vy(r,2:7)).^(1/alpha); % Certainty equivalents for the 1st fitting step with varying amounts of money
    elseif gains==false;
        vx(r,:) = -(-order(:,1)).^alpha; % Value function of x
        vy(r,:) = -(-order(:,2)).^alpha; % Value function of y
        CEfit = -(-(wp26*(vx(r,2:7)-vy(r,2:7))+vy(r,2:7))).^(1/alpha); % Take the v(x) and v(y) with p = 2/6
    end
    % 2nd step: w(p)s from the probability weighting function
    probs = [1/6 3/6 4/6 5/6];
    wpfit = (delta*probs.^gamma)./(((delta*probs.^gamma)+((1-probs).^gamma)));
    
    % Transform relevant data into log or log-odds scale
    % If it's losses, transform CE values to positive first to avoid problems
    % with imaginary numbers. Transform back to negative later. 
    CE = abs(CE);
    CEfit = abs(CEfit);
    
    logCE = log(CE);
    logCEfit(r,:) = log(CEfit);
    logowp = log(wp./(1-wp));
    logowpfit(r,:) = log(wpfit./(1-wpfit));
    
    % Calculate Mean Squared Error (MSE) in the log or log-odds
    % scale
    error1 = logCE-logCEfit(r,:);
    MSE1(r) = mean(error1.^2);
    error2 = logowp-logowpfit(r,:);
    MSE2(r) = mean(error2.^2);
    
end

% Take median RMSE over all subjects and conditions as the standard error
% of the random noise
noisevar1 = median(sqrt(MSE1)); % 1st fitting step
noisevar2 = median(sqrt(MSE2)); % 2nd fitting step

for r = 1:rows
    
    % Add noise to log / log-odds transformed values
    CEfit_noise_log = logCEfit(r,:) + noisevar1.*randn(size(logCEfit(r,:))); % Added noise
    wpfit_noise_log = logowpfit(r,:) + noisevar2.*randn(size(logowpfit(r,:)));
    
    % Transform back to original scale (and CE to negative if losses)
    % CE back from log scale
    if gains==true
        CE_noise(r,2:7) = exp(CEfit_noise_log);
    elseif gains==false
        CE_noise(r,2:7) = -exp(CEfit_noise_log);
    end
    % w(p) back from log-odds scale to probabilities
    wp_noise = exp(wpfit_noise_log)./(1+exp(wpfit_noise_log));
    
    alpha = resultdata(r,14); % Get alpha again for the current row
    
    % Calculate CE based on w(p)
    if gains==true;
        CE_noise(r,[1 8:10]) = (wp_noise.*vx(r,[1 8:10])).^(1/alpha); % Calculate CE from w(p) and v(x) for x = 1200, y = 0, p variable
    elseif gains==false;
        CE_noise(r,[1 8:10]) = -(-wp_noise.*vx(r,[1 8:10])).^(1/alpha);
    end
    
end

end