datapath = 'C:\Users\kojala\Dropbox\Projects\CE_task_analyses\MATLAB_Data';

gainsdata = importdata(fullfile(datapath,'gainsdata_alphaestimated_LattimorePWF_iter200_new.mat'));
lossesdata = importdata(fullfile(datapath,'lossesdata_alphaestimated_LattimorePWF_iter200_new.mat'));
gainsfit = importdata(fullfile(datapath,'modelfit_mlecov_gains_allsubs.mat')); % standard errors from the model covariance matrix
lossesfit = importdata(fullfile(datapath,'modelfit_mlecov_losses_allsubs.mat'));

subjects = [1:20 22 23 29:37 39:42 44:50 52]; % all subjects

placeboind = find(gainsdata(:,3)==1); % indices for drug conditions
sulpirideind = find(gainsdata(:,3)==2); % same indices for gains and losses

% Alpha & w(2/6)
alpha = [gainsdata(placeboind,14) gainsdata(sulpirideind,14) lossesdata(placeboind,14) lossesdata(sulpirideind,14)];
alphaSE = [gainsfit.sderrorP_alpha' gainsfit.sderrorS_alpha' lossesfit.sderrorP_alpha' lossesfit.sderrorS_alpha']; % standard errors
wp26 = [gainsdata(placeboind,16) gainsdata(sulpirideind,16) lossesdata(placeboind,16) lossesdata(sulpirideind,16)];
wp26SE = [gainsfit.sderrorP_wp26' gainsfit.sderrorS_wp26' lossesfit.sderrorP_wp26' lossesfit.sderrorS_wp26']; % standard errors

% Parameter estimates weighted by their standard error
alphaW = alpha./alphaSE;
wp26W = wp26./wp26SE;

% Delta & gamma
delta = [gainsdata(placeboind,20) gainsdata(sulpirideind,20) lossesdata(placeboind,20) lossesdata(sulpirideind,20)];
deltaSE = [gainsfit.sderrorP_delta' gainsfit.sderrorS_delta' lossesfit.sderrorP_delta' lossesfit.sderrorS_delta']; % standard errors
gamma = [gainsdata(placeboind,21) gainsdata(sulpirideind,21) lossesdata(placeboind,21) lossesdata(sulpirideind,21)];
gammaSE = [gainsfit.sderrorP_gamma' gainsfit.sderrorS_gamma' lossesfit.sderrorP_gamma' lossesfit.sderrorS_gamma']; % standard errors

% Parameter estimates weighted by their standard error
deltaW = delta./deltaSE;
gammaW = gamma./gammaSE;

% Weighting after taking the difference for gamma sulpiride-placebo
gammaDrug = gamma(:,2)-gamma(:,1);
gammaSE_avg = mean([gammaSE(:,2) gammaSE(:,1)],2);
gammaW_Drug = gammaDrug./gammaSE_avg;

save(fullfile(datapath,'weighted_parameters.mat'),'alphaW','wp26W','deltaW','gammaW','gammaW_Drug')